aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v1/resources/billing_setup.proto
diff options
context:
space:
mode:
authorGoogle APIs <noreply@google.com>2020-03-11 01:57:58 -0700
committerCopybara-Service <copybara-worker@google.com>2020-03-11 01:58:24 -0700
commitbf839ae632e0f263a729569e44be4b38b1c85f9c (patch)
tree919a9dc3d3cdd1acb586c451bade10baa9080866 /google/ads/googleads/v1/resources/billing_setup.proto
parent309b899ca18a4c604bce63882a161d44854da549 (diff)
downloadgoogleapis-bf839ae632e0f263a729569e44be4b38b1c85f9c.tar.gz
Adding protocol buffer annotations and updated config info for v1 and v2.
PiperOrigin-RevId: 300276913
Diffstat (limited to 'google/ads/googleads/v1/resources/billing_setup.proto')
-rw-r--r--google/ads/googleads/v1/resources/billing_setup.proto78
1 files changed, 47 insertions, 31 deletions
diff --git a/google/ads/googleads/v1/resources/billing_setup.proto b/google/ads/googleads/v1/resources/billing_setup.proto
index ff98ce0a2..efaa11d4c 100644
--- a/google/ads/googleads/v1/resources/billing_setup.proto
+++ b/google/ads/googleads/v1/resources/billing_setup.proto
@@ -1,4 +1,4 @@
-// Copyright 2019 Google LLC.
+// Copyright 2020 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
@@ -11,7 +11,6 @@
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
-//
syntax = "proto3";
@@ -19,6 +18,8 @@ package google.ads.googleads.v1.resources;
import "google/ads/googleads/v1/enums/billing_setup_status.proto";
import "google/ads/googleads/v1/enums/time_type.proto";
+import "google/api/field_behavior.proto";
+import "google/api/resource.proto";
import "google/protobuf/wrappers.proto";
import "google/api/annotations.proto";
@@ -36,49 +37,59 @@ option ruby_package = "Google::Ads::GoogleAds::V1::Resources";
// A billing setup, which associates a payments account and an advertiser. A
// billing setup is specific to one advertiser.
message BillingSetup {
+ option (google.api.resource) = {
+ type: "googleads.googleapis.com/BillingSetup"
+ pattern: "customers/{customer}/billingSetups/{billing_setup}"
+ };
+
// Container of payments account information for this billing.
message PaymentsAccountInfo {
// A 16 digit id used to identify the payments account associated with the
// billing setup.
//
// This must be passed as a string with dashes, e.g. "1234-5678-9012-3456".
- google.protobuf.StringValue payments_account_id = 1;
+ google.protobuf.StringValue payments_account_id = 1 [(google.api.field_behavior) = OUTPUT_ONLY];
- // The name of the payments account associated with the billing setup.
+ // Immutable. The name of the payments account associated with the billing setup.
//
// This enables the user to specify a meaningful name for a payments account
// to aid in reconciling monthly invoices.
//
// This name will be printed in the monthly invoices.
- google.protobuf.StringValue payments_account_name = 2;
+ google.protobuf.StringValue payments_account_name = 2 [(google.api.field_behavior) = IMMUTABLE];
- // A 12 digit id used to identify the payments profile associated with the
+ // Immutable. A 12 digit id used to identify the payments profile associated with the
// billing setup.
//
// This must be passed in as a string with dashes, e.g. "1234-5678-9012".
- google.protobuf.StringValue payments_profile_id = 3;
+ google.protobuf.StringValue payments_profile_id = 3 [(google.api.field_behavior) = IMMUTABLE];
- // The name of the payments profile associated with the billing setup.
- google.protobuf.StringValue payments_profile_name = 4;
+ // Output only. The name of the payments profile associated with the billing setup.
+ google.protobuf.StringValue payments_profile_name = 4 [(google.api.field_behavior) = OUTPUT_ONLY];
- // A secondary payments profile id present in uncommon situations, e.g.
+ // Output only. A secondary payments profile id present in uncommon situations, e.g.
// when a sequential liability agreement has been arranged.
- google.protobuf.StringValue secondary_payments_profile_id = 5;
+ google.protobuf.StringValue secondary_payments_profile_id = 5 [(google.api.field_behavior) = OUTPUT_ONLY];
}
// The resource name of the billing setup.
// BillingSetup resource names have the form:
//
// `customers/{customer_id}/billingSetups/{billing_setup_id}`
- string resource_name = 1;
+ string resource_name = 1 [
+ (google.api.field_behavior) = IMMUTABLE,
+ (google.api.resource_reference) = {
+ type: "googleads.googleapis.com/BillingSetup"
+ }
+ ];
- // The ID of the billing setup.
- google.protobuf.Int64Value id = 2;
+ // Output only. The ID of the billing setup.
+ google.protobuf.Int64Value id = 2 [(google.api.field_behavior) = OUTPUT_ONLY];
- // The status of the billing setup.
- google.ads.googleads.v1.enums.BillingSetupStatusEnum.BillingSetupStatus status = 3;
+ // Output only. The status of the billing setup.
+ google.ads.googleads.v1.enums.BillingSetupStatusEnum.BillingSetupStatus status = 3 [(google.api.field_behavior) = OUTPUT_ONLY];
- // The resource name of the payments account associated with this billing
+ // Immutable. The resource name of the payments account associated with this billing
// setup. Payments resource names have the form:
//
// `customers/{customer_id}/paymentsAccounts/{payments_account_id}`
@@ -86,14 +97,19 @@ message BillingSetup {
// account (and then payments_account_info should not be set).
// When getting a billing setup, this and payments_account_info will be
// populated.
- google.protobuf.StringValue payments_account = 11;
-
- // The payments account information associated with this billing setup.
+ google.protobuf.StringValue payments_account = 11 [
+ (google.api.field_behavior) = IMMUTABLE,
+ (google.api.resource_reference) = {
+ type: "googleads.googleapis.com/PaymentsAccount"
+ }
+ ];
+
+ // Immutable. The payments account information associated with this billing setup.
// When setting up billing, this is used to signup with a new payments account
// (and then payments_account should not be set).
// When getting a billing setup, this and payments_account will be
// populated.
- PaymentsAccountInfo payments_account_info = 12;
+ PaymentsAccountInfo payments_account_info = 12 [(google.api.field_behavior) = IMMUTABLE];
// When creating a new billing setup, this is when the setup should take
// effect. NOW is the only acceptable start time if the customer doesn't have
@@ -103,21 +119,21 @@ message BillingSetup {
// However, if the setup was approved (see status) after the requested start
// time, then this is the approval time.
oneof start_time {
// The start date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format. Only a
// future time is allowed.
- google.protobuf.StringValue start_date_time = 9;
+ google.protobuf.StringValue start_date_time = 9 [(google.api.field_behavior) = IMMUTABLE];
- // The start time as a type. Only NOW is allowed.
- google.ads.googleads.v1.enums.TimeTypeEnum.TimeType start_time_type = 10;
+ // Immutable. The start time as a type. Only NOW is allowed.
+ google.ads.googleads.v1.enums.TimeTypeEnum.TimeType start_time_type = 10 [(google.api.field_behavior) = IMMUTABLE];
}
// When the billing setup ends / ended. This is either FOREVER or the start
// time of the next scheduled billing setup.
oneof end_time {
- // The end date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format.
- google.protobuf.StringValue end_date_time = 13;
+ // Output only. The end date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format.
+ google.protobuf.StringValue end_date_time = 13 [(google.api.field_behavior) = OUTPUT_ONLY];
- // The end time as a type. The only possible value is FOREVER.
- google.ads.googleads.v1.enums.TimeTypeEnum.TimeType end_time_type = 14;
+ // Output only. The end time as a type. The only possible value is FOREVER.
+ google.ads.googleads.v1.enums.TimeTypeEnum.TimeType end_time_type = 14 [(google.api.field_behavior) = OUTPUT_ONLY];
}
}
@@ -36,49 +37,59 @@ option ruby_package = "Google::Ads::GoogleAds::V1::Resources";
// Container of payments account information for this billing.
message PaymentsAccountInfo {
- // A 16 digit id used to identify the payments account associated with the
+ // Output only. A 16 digit id used to identify the payments account associated with the
// billing setup.
//
@@ -36,49 +37,59 @@ option ruby_package = "Google::Ads::GoogleAds::V1::Resources";
}
- // The resource name of the billing setup.
+ // Immutable. The resource name of the billing setup.
// BillingSetup resource names have the form:
//
@@ -103,21 +119,21 @@ message BillingSetup {
// time, then this is the approval time.
oneof start_time {
- // The start date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format. Only a
+ // Immutable. The start date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format. Only a
// future time is allowed.